==> Products.ImageEditor-1.2b3.zip: Products.ImageEditor-1.2b3/Products/ImageEditor/tests/base.py <==
import unittest
import sys
from cStringIO import StringIO

from PIL import Image
from PIL import ImageChops
from PIL import ImageEnhance

from Products.ImageEditor.adapters.imageeditor import ImageEditorAdapter

from zope.testing import doctestunit
from zope.component import testing
from Testing import ZopeTestCase as ztc

from Products.Five import zcml
from Products.Five import fiveconfigure
from Products.PloneTestCase import PloneTestCase as ptc
from Products.PloneTestCase.layer import PloneSite
from Products.PloneTestCase.layer import onsetup
from Products.CMFCore.utils import getToolByName
from Products.ImageEditor.Extensions import Install

from zope.app import zapi
from zope.configuration import xmlconfig

BASE_DIR = ""

for path in sys.path:
    if 'Products.ImageEditor' in path:
        BASE_DIR = path

import Products.ImageEditor, collective.js.jqueryui, collective.js.jquery

@onsetup
def setUp():
    fiveconfigure.debug_mode = True
    zcml.load_config('configure.zcml', Products.ImageEditor)
    zcml.load_config('configure.zcml', collective.js.jquery)
    zcml.load_config('configure.zcml', collective.js.jqueryui)
    fiveconfigure.debug_mode = False
    ztc.installProduct('ImageEditor')
    ztc.installPackage('collective.js.jquery')
    ztc.installPackage('collective.js.jqueryui')

setUp()

ptc.setupPloneSite(extension_profiles=('Products.ImageEditor:default',))

class ImageEditorTestCase(ptc.PloneTestCase):
    """
    """
    def afterSetUp(self):
        self.setRoles(('Manager',))
        
    def getImageContentType(self):
        try:
            id = self.portal.invokeFactory(type_name="Image", id="testimage")
        except Exception:
            id = 'testimage'
        image = self.portal[id]
        image.setTitle('test')
        #(Pdb) p context.getField('image').get(context)
        #<Image at /plone/bug-mantis-01.png/image>
        #(Pdb) p context.getField('image').get(context).data
        #<OFS.Image.Pdata object at 0xb277db6c>
        #(Pdb) p context.getField('image').get(context).data.data
        #'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x04N\x00\x00...
        #...
        #
        #In testcase:
        #(Pdb) image.getField('image').get(image)                                                                         
        #<Image at /plone/testimage/image>                                                                                
        #(Pdb) image.getField('image').get(image).data                                                                    
        #'\xff\xd8\xff\xe0\x00\x10JFIF\x00\x01\...
        im = self.getOriginal()
        imageData = StringIO()
        im.save(imageData, im.format)
        image.setImage(imageData)
        return image
    
    def uninstall(self):
        getToolByName(self.portal, 'portal_quickinstaller').uninstallProducts(['ImageEditor'])
    
    def getEditor(self, context):
        return ImageEditorAdapter(context)
    
    def getImageEditorAdapter(self):
        image = self.getImageContentType()
        return ImageEditorAdapter(image)
       
    def imagesEqual(self, comparedImageFileName, imageEditor):
        imageEditor.save_edit()
        imageEditor.get_current_image().save(self.getImagePath(comparedImageFileName))
        
        imgfile = self.getImage(comparedImageFileName)
        
        image_diff = ImageChops.difference(imgfile, imageEditor.get_current_image()).getbbox()
        
        #self.failUnless(image_diff[0] == 0 and image_diff[1] == 0)
        
        #doesn't ever work...  Why aren't images the same??
        #self.failUnless(image_diff is None)
        
    def getOriginal(self):
        return self.getImage('original.jpg')
        
    def getImagePath(self, name):
        return '%s/Products/ImageEditor/tests/testimages/%s' % (BASE_DIR, name)
        
    def getImage(self, name):
        return Image.open(self.getImagePath(name))

==> Products.ImageEditor-2.1.0.zip: Products.ImageEditor-2.1.0/Products/ImageEditor/tests/base.py <==
from StringIO import StringIO
from os.path import dirname, join
from PIL import Image
from Products.PloneTestCase import ptc
from Products.CMFCore.utils import getToolByName
from Products.ImageEditor import testing, tests
from Products.ImageEditor.adapters.imageeditor import ImageEditorAdapter


ptc.setupPloneSite()
ptc.utils.setupCoreSessions()


class ImageEditorTestCase(ptc.PloneTestCase):
    """ base class for integration tests """

    layer = testing.basic

    def afterSetUp(self):
        self.setRoles(('Manager',))
        # put SESSION object into REQUEST
        sdm = self.app.session_data_manager
        self.app.REQUEST.set('SESSION', sdm.getSessionData())

    def getImageContentType(self):
        try:
            images_folder = self.portal.invokeFactory(type_name="Folder", id="images_folder")
        except Exception:
            images_folder = "images_folder"

        try:

            id = self.portal['images_folder'].invokeFactory(type_name="Image", id="testimage")
        except Exception:
            id = 'testimage'
        image = self.portal[images_folder][id]
        image.setTitle('test')
        #(Pdb) p context.getField('image').get(context)
        #<Image at /plone/bug-mantis-01.png/image>
        #(Pdb) p context.getField('image').get(context).data
        #<OFS.Image.Pdata object at 0xb277db6c>
        #(Pdb) p context.getField('image').get(context).data.data
        #'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x04N\x00\x00...
        #...
        #
        #In testcase:
        #(Pdb) image.getField('image').get(image)
        #<Image at /plone/testimage/image>
        #(Pdb) image.getField('image').get(image).data
        #'\xff\xd8\xff\xe0\x00\x10JFIF\x00\x01\...
        im = self.getOriginal()
        imageData = StringIO()
        im.save(imageData, im.format)
        image.setImage(imageData)
        return image

    def uninstall(self):
        setup_tool = getToolByName(self.portal, 'portal_setup')
        setup_tool.runAllImportStepsFromProfile('profile-Products.ImageEditor:uninstall')

    def getEditor(self, context):
        return ImageEditorAdapter(context)

    def getImageEditorAdapter(self):
        image = self.getImageContentType()
        return ImageEditorAdapter(image)

    def getOriginal(self):
        return self.getImage('original.jpg')

    def getImagePath(self, name):
        return join(dirname(tests.__file__), 'testimages', name)

    def getImage(self, name):
        return Image.open(self.getImagePath(name))
